@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,13 @@
 
 static LList *my_arrows = NULL;
 
+/**
+ * Find an arrow of a given type. 
+ *
+ * @param[in] type	The type of the arrow to find
+ *
+ * @return an arrow of the correct type, or NULL if not found.
+ */
 static Arrow *arrow_find(ArrowType type)
 {
 	LList *cur = my_arrows;
@@ -49,6 +56,9 @@ static Arrow *arrow_find(ArrowType type)
 
 static SDL_Surface *arrow_models[NUM_ARROWS] = {NULL};
 
+/**
+ * Initialise arrow models from the images
+ */
 static void init_arrow_models(void)
 {
 	int i = 0;
@@ -67,11 +77,18 @@ static void init_arrow_models(void)
 		assert(arrow_models[i] != NULL);
 }
 
+/**
+ * Get an arrow of a given type. 
+ *
+ * @param[in] type	The type of the arrow to get
+ *
+ * @return an arrow of the correct type.
+ */
 Arrow *arrow_get (ArrowType type)
 {
-	Arrow *new_arrow = NULL;
-	if (arrow_find(type))
-		return arrow_find(type);
+	Arrow *new_arrow = arrow_find(type);
+	if (new_arrow != NULL)
+		return new_arrow;
 	
 	if (arrow_models[ARROW_UP] == NULL)
 		init_arrow_models();
@@ -81,9 +98,20 @@ Arrow *arrow_get (ArrowType type)
 	new_arrow->type = type;
 	new_arrow->surface = arrow_models[new_arrow->type];
 	
+	my_arrows = llist_append(my_arrows, new_arrow);
+
 	return new_arrow;
 }
 
+/**
+ * Draw an arrow of a given type. 
+ *
+ * @param[in] type	The type of the arrow to get
+ * @param[in] x		The X coordinate (pixels)
+ * @param[in] y		The Y coordinate (pixels)
+ *
+ * @return an arrow of the correct type.
+ */
 void arrow_draw(ArrowType type, int x, int y)
 {
 	Arrow *arrow = arrow_get(type);
@@ -92,7 +120,12 @@ void arrow_draw(ArrowType type, int x, int y)
 		SDL_UpdateRect(screen, x, y, 20, 20);
 }
 
-int arrow_draw_all(Player *player)
+/**
+ * Draw all arrows for re-placing pawns that just ate one.
+ *
+ * @param[in] player	The player for which we want to draw arrows
+ */
+void arrow_draw_all(Player *player)
 {
 	LList *pawns = pawn_get_replacement_pending_pawns(player->color);
 	LList *cur = pawns;
@@ -102,25 +135,11 @@ int arrow_draw_all(Player *player)
 		LList *to_tiles = pawn->just_ate_on;
 		while(to_tiles) {
 			Tile *to_tile = (Tile *)to_tiles->data;
-#if 1 /* this allows replacement of one pawn per pair everytime */
 			tile_draw_arrow(pawn_get_tile(pawn), to_tile);
-#else /* this allows replacement of one pawn per pair only if the second is still there */
-			Tile *third = tile_get_next_in_row(pawn_get_tile(pawn), to_tile);
-			
-			if (third && third->pawn &&
-			    llist_find(third->pawn->just_ate_on, to_tile))
-				tile_draw_arrow(pawn_get_tile(pawn), to_tile);
-			else {
-				pawn->just_ate_on = llist_remove(pawn->just_ate_on, to_tile);
-				SDL_UpdateRect(screen, 0, 0, 0, 0);
-				return TRUE;
-			}
-#endif
 			to_tiles = to_tiles->next;
 		}
 		cur = cur->next;
 	}
 	llist_free(pawns);
 	SDL_UpdateRect(screen, 0, 0, 0, 0);
-	return FALSE;
 }
