@@ -24,7 +24,7 @@
 
 void board_build(void);
 void board_destroy(void);
-void board_set_player(Player *player);
+void board_set_player(Player *player, int display_your_turn);
 void board_freeze(void);
 void board_thaw(void);
 int  board_frozen(void);
