@@ -53,7 +53,7 @@ static int first = FALSE;
 static Tile *computer_defend(Player *player, LList *allowed, int immediate_defense)
 {
 	/* get the best pawn to move so that it won't be eaten */
-	LList *pawns = allowed ? allowed : pawn_get_all(player->color);
+	LList *pawns;
 	LList *cur;
 	Tile *best = NULL;
 	LList *max_eaten_pawns = NULL;
@@ -61,6 +61,11 @@ static Tile *computer_defend(Player *player, LList *allowed, int immediate_defen
 	int search_now = (immediate_defense > 0);
 	int center_ok = can_move_on_center();
 
+	if (allowed)
+		pawns = llist_copy(allowed);
+	else
+		pawns = pawn_get_all(player->color);
+
 search_again:	
 	max_eaten_pawns = player_can_be_eaten(player, search_now, allowed);
 	max_eaten = llist_length(max_eaten_pawns);
@@ -119,6 +124,8 @@ search_again:
 		goto search_again;
 	}
 
+	llist_free(pawns);
+
 	return best;
 }
 
@@ -182,14 +189,20 @@ static Tile *finish_move(Player *player, LList *allowed)
 static Tile *prepare_move(Player *player, LList *allowed)
 {
 	/* get the best pawn to move so that I'll be able to eat later */
-	LList *pawns = allowed ? allowed : pawn_get_all(player->color);
-	LList *cur = pawns;
+	LList *pawns, *cur;
 	Pawn *best = NULL;
 	int max_eatables_soon = 0;
-	int pawn_count = llist_length(pawns);
+	int pawn_count;
 	int search_now = TRUE;
 
-	if (llist_length(pawns) == 1) {
+	if (allowed)
+		pawns = llist_copy(allowed);
+	else
+		pawns = pawn_get_all(player->color);
+
+	pawn_count = llist_length(pawns);
+
+	if (pawn_count == 1) {
 		Pawn *pawn = (Pawn *)pawns->data;
 		if (pawn_get_tile(pawn)->type == TILE_CENTER) {
 			/* move again */
@@ -198,10 +211,12 @@ static Tile *prepare_move(Player *player, LList *allowed)
 		} 
 	}
 
-	if (selected_pawn != NULL)
+	if (selected_pawn != NULL) {
+		llist_free(pawns);
 		return finish_move(player, allowed);
-
+	}
 	if (first) {
+		llist_free(pawns);
 		selected_pawn = tile_get(4,3)->pawn;
 		return tile_get(4,3);
 	}
@@ -234,7 +249,7 @@ search_again:
 					if (!llist_find(positions, cur_mid->data))
 						llist_append(positions, cur_mid->data);
 				}
-				llist_free(cur_mid);
+				llist_free(mid_surr);
 				continue;
 			}
 			can_be_eaten = player_can_be_eaten(player, search_now, allowed_for_this);
@@ -343,8 +358,7 @@ random_again:
 
 	}
 no_random:
-	if (allowed == NULL)
-		llist_free(pawns);
+	llist_free(pawns);
 	
 	selected_pawn = best;
 
