@@ -31,7 +31,9 @@ typedef enum {
 	M_NEWGAME,
 	M_ENOCONN,
 	M_PLAYER_LEAVES,
-	M_LEAVES
+	M_LEAVES,
+	M_YOUR_TURN,
+	M_NUM_MSGS
 } MsgId;
 
 const char *get_msg(MsgId id);
